/**   \file  suite_libdebug-assert.c
 *   \brief  Check Libdebug assert functions
 *  \author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  \internal
 *       Created:  26/06/2024
 *      Revision:  none
 * Last modified:  2024-07-27 17:33
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "debug/assert.h"                       /* libdebug's assertions */
#include "oom.h"                                /* OOM simulation */
#include "debug/memtrack.h"                     /* memtrack_dumpblocks */
#include <check.h>
#include <unistd.h>                             /* pid_t getpid() */
#include <sys/stat.h>                           /* mkdir(), chdir(), mode_t */
#include <stdio.h>                              /* fprintf */
#include <stdlib.h>                             /* abort() */
#include "checktools.inc"

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_nullfile)
{
    /* The function does not return anything or change any value, I can not
     * check if it worked. I can only expect it to work or to SIGSEV the process */
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(NULL,__LINE__,__DATE__,__TIME__,__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_nullline)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,0,__DATE__,__TIME__,__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_nulldate)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,NULL,__TIME__,__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_nulltime)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,__DATE__,NULL,__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_nullfunc)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,__DATE__,__TIME__,NULL);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_emptyfile)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace("",__LINE__,__DATE__,__TIME__,__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_emptydate)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,"",__TIME__,__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_emptytime)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,__DATE__,"",__func__);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace with NULL or empty input strings */
START_TEST(assert_trace_emptyfunc)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,__DATE__,__TIME__,"");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
START_TEST(assert_trace_value)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    oomtest_fill(_i,2);
    _trace(szLongString,__LINE__,__DATE__,__TIME__,__func__);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,szLongString,__TIME__,__func__);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,__DATE__,szLongString,__func__);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace(__FILE__,__LINE__,__DATE__,__TIME__,szLongString);
    oomtest_free();
}
END_TEST
#endif /* NDEBUG */



#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_nullfile)
{
    /* The function does not return anything or change any value, I can not
     * check if it worked. I can only expect it to work or to SIGSEV the process */
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(NULL,__LINE__,__DATE__,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_nullline)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,0,__DATE__,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_nulldate)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,NULL,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_nulltime)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,NULL,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_nullfunc)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,__TIME__,NULL,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_nullmsg)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,__TIME__,NULL,NULL);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_emptyfile)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg("",__LINE__,__DATE__,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_emptydate)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,"",__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_emptytime)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,"",__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_emptyfunc)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,__TIME__,"","message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_msg with NULL or empty input strings */
START_TEST(assert_tracemsg_emptymsg)
{
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,"");
    oomtest_free();
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
START_TEST(assert_tracemsg_value)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    oomtest_fill(_i,2);
    _trace_msg(szLongString,__LINE__,__DATE__,__TIME__,__func__,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,szLongString,__TIME__,__func__,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,szLongString,__func__,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,__TIME__,szLongString,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_msg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szLongString);
    oomtest_free();
}
END_TEST
#endif /* NDEBUG */



#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_nullfile)
{
    /* The function does not return anything or change any value, I can not
     * check if it worked. I can only expect it to work or to SIGSEV the process */
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(NULL,__LINE__,__DATE__,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_nullline)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,0,__DATE__,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_nulldate)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,NULL,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_nulltime)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,NULL,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_nullfunc)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,NULL,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_nullmsg)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,NULL,NULL);
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_emptyfile)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg("",__LINE__,__DATE__,__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_emptydate)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,"",__TIME__,__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_emptytime)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,"",__func__,"message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_emptyfunc)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,"","message");
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
/** Test _trace_dynmsg with NULL or empty input strings */
START_TEST(assert_tracedynmsg_emptymsg)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,"");
    oomtest_free();
}
END_TEST
#endif /* NDEBUG */

#ifndef NDEBUG
START_TEST(assert_tracedynmsg_value)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    char *szParamLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "%d"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    oomtest_fill(_i,2);
    _trace_dynmsg(szLongString,__LINE__,__DATE__,__TIME__,__func__,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,szLongString,__TIME__,__func__,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,szLongString,__func__,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,szLongString,"message");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szLongString);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szLongString,NULL);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szLongString,"");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szLongString,"abc");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szLongString,123);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szParamLongString);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szParamLongString,NULL);
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szParamLongString,"");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szParamLongString,"abc");
    oomtest_free();
    oomtest_fill(_i,2);
    _trace_dynmsg(__FILE__,__LINE__,__DATE__,__TIME__,__func__,szParamLongString,123);
    oomtest_free();
}
END_TEST
#endif /* NDEBUG */

START_TEST(assert_assert_true)
{
    oomtest_fill(_i,2);
    ASSERT(1);
    oomtest_free();
}
END_TEST

START_TEST(assert_assert_false)
{
    forktest_only;
#ifdef GCOV
    if(oomtest_enabled())
        __gcov_dump();
#endif
    oomtest_fill(_i,2);
    ASSERT(0);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgtrace)
{
    oomtest_fill(_i,2);
    DBG_TRACE;
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgmsg_null)
{
    oomtest_fill(_i,2);
    DBG_MSG(NULL);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgmsg_empty)
{
    oomtest_fill(_i,2);
    DBG_MSG("");
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgmsg_szlong)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_MSG(szLongString);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgitrace_inst)
{
    unsigned int result;
    result=0;
    oomtest_fill(_i,2);
    DBG_ITRACE(result=1);
    oomtest_free();
    ck_assert(1==result);
}
END_TEST

START_TEST(assert_dbgprintf_null_null)
{
    oomtest_fill(_i,2);
    DBG_PRINTF(NULL,NULL);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_null_empty)
{
    oomtest_fill(_i,2);
    DBG_PRINTF(NULL,"");
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_null_szlong)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(NULL,szLongString);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_null_123)
{
    oomtest_fill(_i,2);
    DBG_PRINTF(NULL,123);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_empty_null)
{
    oomtest_fill(_i,2);
    DBG_PRINTF("",NULL);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_empty_empty)
{
    oomtest_fill(_i,2);
    DBG_PRINTF("","");
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_empty_szlong)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF("",szLongString);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_empty_123)
{
    oomtest_fill(_i,2);
    DBG_PRINTF("",123);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szlong_null)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szLongString,NULL);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szlong_empty)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szLongString,"");
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szlong_szlong)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szLongString,szLongString);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szlong_123)
{
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szLongString,123);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szparamlong_null)
{
    char *szParamLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "%d"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szParamLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szParamLongString,NULL);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szparamlong_empty)
{
    char *szParamLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "%d"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szParamLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szParamLongString,"");
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szparamlong_szlong)
{
    char *szParamLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "%d"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    char *szLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szParamLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    (void)szLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szParamLongString,szLongString);
    oomtest_free();
}
END_TEST

START_TEST(assert_dbgprintf_szparamlong_123)
{
    char *szParamLongString =
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "%d"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        ;
    (void)szParamLongString; /* Avoid error/warning when NDEBUG voids macro to test */
    oomtest_fill(_i,2);
    DBG_PRINTF(szParamLongString,123);
    oomtest_free();
}
END_TEST

/************************************************************************/
void assert_checked_uninitialized_setup()
{
    signals_catch();
    forktest_gprofdir();
}
void assert_checked_common_teardown()
{
    signals_release();
#ifndef NDEBUG
    ck_assert(0==memtrack_getallocatedblocks());
#endif /* NDEBUG */
}
/************************************************************************/
void assert_unchecked_common_setup()
{
    forktest_init();
}
void assert_unchecked_common_teardown()
{
}
void assert_unchecked_oom_setup()
{
    oomtest_enable(RAMLIMIT_SOFT);
    assert_unchecked_common_setup();
}
void assert_unchecked_oom_teardown()
{
    oomtest_disable();
    assert_unchecked_common_teardown();
}
/************************************************************************/
Suite* libdebug_assert_suite()
{
    Suite *s;
    TCase *tc;

    s = suite_create("LibDebug-Assert");
    tc = tcase_create("Uninitialized");
    tcase_add_checked_fixture(tc, assert_checked_uninitialized_setup, assert_checked_common_teardown);
    tcase_add_unchecked_fixture(tc, assert_unchecked_common_setup, assert_unchecked_common_teardown);
    suite_add_tcase(s, tc);
#ifndef NDEBUG
    tcase_add_test_raise_signal(tc, assert_trace_nullfile,6);
    tcase_add_test_raise_signal(tc, assert_trace_nullline,6);
    tcase_add_test_raise_signal(tc, assert_trace_nulldate,6);
    tcase_add_test_raise_signal(tc, assert_trace_nulltime,6);
    tcase_add_test_raise_signal(tc, assert_trace_nullfunc,6);
    tcase_add_test_raise_signal(tc, assert_trace_emptyfile,6);
    tcase_add_test_raise_signal(tc, assert_trace_emptydate,6);
    tcase_add_test_raise_signal(tc, assert_trace_emptytime,6);
    tcase_add_test_raise_signal(tc, assert_trace_emptyfunc,6);
    tcase_add_test(tc, assert_trace_value);
    tcase_add_test_raise_signal(tc, assert_tracemsg_nullfile,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_nullline,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_nulldate,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_nulltime,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_nullfunc,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_nullmsg,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_emptyfile,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_emptydate,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_emptytime,6);
    tcase_add_test_raise_signal(tc, assert_tracemsg_emptyfunc,6);
    tcase_add_test(tc, assert_tracemsg_emptymsg);
    tcase_add_test(tc, assert_tracemsg_value);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_nullfile,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_nullline,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_nulldate,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_nulltime,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_nullfunc,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_nullmsg,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_emptyfile,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_emptydate,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_emptytime,6);
    tcase_add_test_raise_signal(tc, assert_tracedynmsg_emptyfunc,6);
    tcase_add_test(tc, assert_tracedynmsg_emptymsg);
    tcase_add_test(tc, assert_tracedynmsg_value);
    tcase_add_test_raise_signal(tc, assert_assert_false,6);
#else
    tcase_add_test(tc, assert_assert_false);
#endif /* NDEBUG */
    tcase_add_test(tc, assert_assert_true);
    tcase_add_test(tc, assert_dbgtrace);
    tcase_add_test(tc, assert_dbgmsg_null);
    tcase_add_test(tc, assert_dbgmsg_empty);
    tcase_add_test(tc, assert_dbgmsg_szlong);
    tcase_add_test(tc, assert_dbgitrace_inst);
    tcase_add_test(tc, assert_dbgprintf_null_null);
    tcase_add_test(tc, assert_dbgprintf_null_empty);
    tcase_add_test(tc, assert_dbgprintf_null_szlong);
    tcase_add_test(tc, assert_dbgprintf_null_123);
    tcase_add_test(tc, assert_dbgprintf_empty_null);
    tcase_add_test(tc, assert_dbgprintf_empty_empty);
    tcase_add_test(tc, assert_dbgprintf_empty_szlong);
    tcase_add_test(tc, assert_dbgprintf_empty_123);
    tcase_add_test(tc, assert_dbgprintf_szlong_null);
    tcase_add_test(tc, assert_dbgprintf_szlong_empty);
    tcase_add_test(tc, assert_dbgprintf_szlong_szlong);
    tcase_add_test(tc, assert_dbgprintf_szlong_123);
    tcase_add_test(tc, assert_dbgprintf_szparamlong_null);
    tcase_add_test(tc, assert_dbgprintf_szparamlong_empty);
    tcase_add_test(tc, assert_dbgprintf_szparamlong_szlong);
    tcase_add_test(tc, assert_dbgprintf_szparamlong_123);

    tc = tcase_create("Uninitialized-OOM");
    tcase_set_tags(tc,"oom");
    tcase_add_checked_fixture(tc, assert_checked_uninitialized_setup, assert_checked_common_teardown);
    tcase_add_unchecked_fixture(tc, assert_unchecked_oom_setup, assert_unchecked_oom_teardown);
    suite_add_tcase(s, tc);
#ifndef NDEBUG
    tcase_add_loop_test_raise_signal(tc, assert_trace_nullfile,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_nullline,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_nulldate,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_nulltime,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_nullfunc,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_emptyfile,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_emptydate,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_emptytime,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_trace_emptyfunc,6, 0, 10);
    tcase_add_loop_test(tc, assert_trace_value, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_nullfile,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_nullline,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_nulldate,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_nulltime,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_nullfunc,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_nullmsg,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_emptyfile,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_emptydate,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_emptytime,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracemsg_emptyfunc,6, 0, 10);
    tcase_add_loop_test(tc, assert_tracemsg_emptymsg, 0, 10);
    tcase_add_loop_test(tc, assert_tracemsg_value, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_nullfile,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_nullline,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_nulldate,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_nulltime,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_nullfunc,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_nullmsg,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_emptyfile,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_emptydate,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_emptytime,6, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_tracedynmsg_emptyfunc,6, 0, 10);
    tcase_add_loop_test(tc, assert_tracedynmsg_emptymsg, 0, 10);
    tcase_add_loop_test(tc, assert_tracedynmsg_value, 0, 10);
    tcase_add_loop_test_raise_signal(tc, assert_assert_false,6, 0, 10);
#else
    tcase_add_loop_test(tc, assert_assert_false, 0, 10);
#endif /* NDEBUG */
    tcase_add_loop_test(tc, assert_assert_true, 0, 10);
    tcase_add_loop_test(tc, assert_dbgtrace, 0, 10);
    tcase_add_loop_test(tc, assert_dbgmsg_null, 0, 10);
    tcase_add_loop_test(tc, assert_dbgmsg_empty, 0, 10);
    tcase_add_loop_test(tc, assert_dbgmsg_szlong, 0, 10);
    tcase_add_loop_test(tc, assert_dbgitrace_inst, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_null_null, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_null_empty, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_null_szlong, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_null_123, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_empty_null, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_empty_empty, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_empty_szlong, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_empty_123, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szlong_null, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szlong_empty, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szlong_szlong, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szlong_123, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szparamlong_null, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szparamlong_empty, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szparamlong_szlong, 0, 10);
    tcase_add_loop_test(tc, assert_dbgprintf_szparamlong_123, 0, 10);

    return s;
}

